@@ -63,6 +63,8 @@ public class CsvGenerator extends GeneratorBase
          * actually need this.
          * Note that this feature has precedence over {@link #STRICT_CHECK_FOR_QUOTING}, when
          * both would be applicable.
+         * Note that this setting does NOT affect quoting of typed values like {@code Number}s
+         * or {@code Boolean}s.
          *
          * @since 2.5
          */
@@ -76,6 +78,15 @@ public class CsvGenerator extends GeneratorBase
          */
         ALWAYS_QUOTE_EMPTY_STRINGS(false),
 
+        /**
+         * Feature that determines whether values written as Nymbers (from {@code java.lang.Number}
+         * valued POJO properties) should be forced to be quoted, regardless of whether they
+         * actually need this.
+         *
+         * @since 2.16
+         */
+        ALWAYS_QUOTE_NUMBERS(false),
+        
         /**
          * Feature that determines whether quote characters within quoted String values are escaped
          * using configured escape character, instead of being "doubled up" (that is: a quote character
@@ -97,7 +108,23 @@ public class CsvGenerator extends GeneratorBase
          *
          * @since 2.9.9
          */
-        ESCAPE_CONTROL_CHARS_WITH_ESCAPE_CHAR(false)
+        ESCAPE_CONTROL_CHARS_WITH_ESCAPE_CHAR(false),
+
+        /**
+         * Feature that determines whether a line-feed will be written at the end of content,
+         * after the last row of output.
+         *<p>
+         * NOTE! When disabling this feature it is important that
+         * {@link #flush()} is NOT called before {@link #close()} is called;
+         * the current implementation relies on ability to essentially remove the
+         * last linefeed that was appended in the output buffer.
+         *<p>
+         * Default value is {@code true} so all rows, including the last, are terminated by
+         * a line feed.
+         *
+         * @since 2.17
+         */
+        WRITE_LINEFEED_AFTER_LAST_ROW(true)
         ;
 
         protected final boolean _defaultState;
@@ -145,8 +172,11 @@ public class CsvGenerator extends GeneratorBase
         EMPTY_SCHEMA = CsvSchema.emptySchema();
     }
     
-    final protected IOContext _ioContext;
-
+    /**
+     * @since 2.16
+     */
+    protected final StreamWriteConstraints _streamWriteConstraints;
+    
     /**
      * Bit flag composed of bits that indicate which
      * {@link CsvGenerator.Feature}s
@@ -191,6 +221,14 @@ public class CsvGenerator extends GeneratorBase
      */
     protected int _nextColumnByName = -1;
 
+    /**
+     * Decorator to use for decorating the column value to follow, if any;
+     * {@code null} if none.
+     *
+     * @since 2.18
+     */
+    protected CsvValueDecorator _nextColumnDecorator;
+
     /**
      * Flag set when property to write is unknown, and the matching value
      * is to be skipped quietly.
@@ -241,11 +279,12 @@ public class CsvGenerator extends GeneratorBase
     public CsvGenerator(IOContext ctxt, int jsonFeatures, int csvFeatures,
             ObjectCodec codec, Writer out, CsvSchema schema)
     {
-        super(jsonFeatures, codec);
-        _ioContext = ctxt;
+        super(jsonFeatures, codec, ctxt);
+        _streamWriteConstraints = ctxt.streamWriteConstraints();
         _formatFeatures = csvFeatures;
         _schema = schema;
-        _writer = new CsvEncoder(ctxt, csvFeatures, out, schema);
+        boolean useFastDoubleWriter = isEnabled(StreamWriteFeature.USE_FAST_DOUBLE_WRITER);
+        _writer = new CsvEncoder(ctxt, csvFeatures, out, schema, useFastDoubleWriter);
         _writeContext = null; // just to make sure it won't be used
         _tokenWriteContext = SimpleTokenWriteContext.createRootContext(null);
         _writer.setOutputEscapes(CsvCharacterEscapes.fromCsvFeatures(csvFeatures).getEscapeCodesForAscii());
@@ -254,8 +293,8 @@ public class CsvGenerator extends GeneratorBase
     public CsvGenerator(IOContext ctxt, int jsonFeatures, int csvFeatures,
             ObjectCodec codec, CsvEncoder csvWriter)
     {
-        super(jsonFeatures, codec);
-        _ioContext = ctxt;
+        super(jsonFeatures, codec, ctxt);
+        _streamWriteConstraints = ctxt.streamWriteConstraints();
         _formatFeatures = csvFeatures;
         _writer = csvWriter;
         _writeContext = null; // just to make sure it won't be used
@@ -430,14 +469,16 @@ public class CsvGenerator extends GeneratorBase
         if (_skipWithin != null) { // new in 2.7
             _skipValue = true;
             _nextColumnByName = -1;
+            _nextColumnDecorator = null;
             return;
         }
         // note: we are likely to get next column name, so pass it as hint
         CsvSchema.Column col = _schema.column(name, _nextColumnByName+1);
         if (col == null) {
+            _nextColumnByName = -1;
+            _nextColumnDecorator = null;
             if (isEnabled(JsonGenerator.Feature.IGNORE_UNKNOWN)) {
                 _skipValue = true;
-                _nextColumnByName = -1;
                 return;
             }
             // not a low-level error, so:
@@ -446,6 +487,7 @@ public class CsvGenerator extends GeneratorBase
         _skipValue = false;
         // and all we do is just note index to use for following value write
         _nextColumnByName = col.getIndex();
+        _nextColumnDecorator = col.getValueDecorator();
     }
 
     /*
@@ -477,6 +519,11 @@ public class CsvGenerator extends GeneratorBase
         return this;
     }
 
+    @Override
+    public StreamWriteConstraints streamWriteConstraints() {
+        return _streamWriteConstraints;
+    }
+
     /*
     /**********************************************************
     /* Public API: low-level I/O
@@ -491,17 +538,18 @@ public class CsvGenerator extends GeneratorBase
     @Override
     public void close() throws IOException
     {
-        super.close();
+        if (!isClosed()) {
+            // Let's mark row as closed, if we had any...
+            finishRow();
 
-        // Let's mark row as closed, if we had any...
-        finishRow();
-        
-        // Write the header if necessary, occurs when no rows written
-        if (_handleFirstLine) {
-            _handleFirstLine();
+            // Write the header if necessary, occurs when no rows written
+            if (_handleFirstLine) {
+                _handleFirstLine();
+            }
+            _writer.close(_ioContext.isResourceManaged() || isEnabled(JsonGenerator.Feature.AUTO_CLOSE_TARGET),
+                    isEnabled(JsonGenerator.Feature.FLUSH_PASSED_TO_STREAM));
+            super.close();
         }
-        _writer.close(_ioContext.isResourceManaged() || isEnabled(JsonGenerator.Feature.AUTO_CLOSE_TARGET),
-                isEnabled(JsonGenerator.Feature.FLUSH_PASSED_TO_STREAM));
     }
 
     /*
@@ -550,6 +598,7 @@ public class CsvGenerator extends GeneratorBase
             }
         }
         _tokenWriteContext = _tokenWriteContext.createChildArrayContext(null);
+        streamWriteConstraints().validateNestingDepth(_tokenWriteContext.getNestingDepth());
         // and that's about it, really
     }
 
@@ -568,8 +617,13 @@ public class CsvGenerator extends GeneratorBase
             return;
         }
         if (!_arraySeparator.isEmpty()) {
+            String value = _arrayContents.toString();
+            // 26-Aug-2024, tatu: [dataformats-text#495] Decorations!
+            if (_nextColumnDecorator != null) {
+                value = _nextColumnDecorator.decorateValue(this, value);
+            }
             _arraySeparator = CsvSchema.NO_ARRAY_ELEMENT_SEPARATOR;
-            _writer.write(_columnIndex(), _arrayContents.toString());
+            _writer.write(_columnIndex(), value);
         }
         // 20-Nov-2014, tatu: When doing "untyped"/"raw" output, this means that row
         //    is now done. But not if writing such an array field, so:
@@ -596,6 +650,7 @@ public class CsvGenerator extends GeneratorBase
             }
         }
         _tokenWriteContext = _tokenWriteContext.createChildObjectContext(null);
+        streamWriteConstraints().validateNestingDepth(_tokenWriteContext.getNestingDepth());
     }
 
     @Override
@@ -634,6 +689,10 @@ public class CsvGenerator extends GeneratorBase
             if (!_arraySeparator.isEmpty()) {
                 _addToArray(text);
             } else {
+                // 26-Aug-2024, tatu: [dataformats-text#495] Decorations!
+                if (_nextColumnDecorator != null) {
+                    text = _nextColumnDecorator.decorateValue(this, text);
+                }
                 _writer.write(_columnIndex(), text);
             }
         }
@@ -646,6 +705,11 @@ public class CsvGenerator extends GeneratorBase
         if (!_skipValue) {
             if (!_arraySeparator.isEmpty()) {
                 _addToArray(new String(text, offset, len));
+            // 26-Aug-2024, tatu: [dataformats-text#495] Decorations!
+            } else if (_nextColumnDecorator != null) {
+                String str = new String(text, offset, len);
+                _writer.write(_columnIndex(),
+                        _nextColumnDecorator.decorateValue(this, str));
             } else {
                 _writer.write(_columnIndex(), text, offset, len);
             }
@@ -660,7 +724,12 @@ public class CsvGenerator extends GeneratorBase
             if (!_arraySeparator.isEmpty()) {
                 _addToArray(sstr.getValue());
             } else {
-                _writer.write(_columnIndex(), sstr.getValue());
+                // 26-Aug-2024, tatu: [dataformats-text#495] Decorations!
+                String text = sstr.getValue();
+                if (_nextColumnDecorator != null) {
+                    text = _nextColumnDecorator.decorateValue(this, text);
+                }
+                _writer.write(_columnIndex(), text);
             }
         }
     }
@@ -741,6 +810,7 @@ public class CsvGenerator extends GeneratorBase
             writeNull();
             return;
         }
+
         _verifyValueWrite("write Binary value");
         if (!_skipValue) {
             // ok, better just Base64 encode as a String...
@@ -752,6 +822,10 @@ public class CsvGenerator extends GeneratorBase
             if (!_arraySeparator.isEmpty()) {
                 _addToArray(encoded);
             } else {
+                // 26-Aug-2024, tatu: [dataformats-text#495] Decorations!
+                if (_nextColumnDecorator != null) {
+                    encoded = _nextColumnDecorator.decorateValue(this, encoded);
+                }
                 _writer.write(_columnIndex(), encoded);
             }
         }
@@ -771,7 +845,13 @@ public class CsvGenerator extends GeneratorBase
             if (!_arraySeparator.isEmpty()) {
                 _addToArray(state ? "true" : "false");
             } else {
-                _writer.write(_columnIndex(), state);
+                // 26-Aug-2024, tatu: [dataformats-text#495] Decorations!
+                if (_nextColumnDecorator != null) {
+                    String text = _nextColumnDecorator.decorateValue(this, state ? "true" : "false");
+                    _writer.write(_columnIndex(), text);
+                } else {
+                    _writer.write(_columnIndex(), state);
+                }
             }
         }
     }
@@ -785,6 +865,15 @@ public class CsvGenerator extends GeneratorBase
             if (!_arraySeparator.isEmpty()) {
                 _addToArray(_schema.getNullValueOrEmpty());
             } else if (_tokenWriteContext.inObject()) {
+                // 26-Aug-2024, tatu: [dataformats-text#495] Decorations?
+                if (_nextColumnDecorator != null) {
+                    String nvl = _nextColumnDecorator.decorateNull(this);
+                    if (nvl != null) {
+                        _writer.write(_columnIndex(), nvl);
+                        return;
+                    }
+                }
+
                 _writer.writeNull(_columnIndex());
             } else if (_tokenWriteContext.inArray()) {
                 // [dataformat-csv#106]: Need to make sure we don't swallow nulls in arrays either
@@ -794,6 +883,14 @@ public class CsvGenerator extends GeneratorBase
                 //   based on either schema property, or CsvGenerator.Feature.
                 //  Note: if nulls are to be written that way, would need to call `finishRow()` right after `writeNull()`
                 if (!_tokenWriteContext.getParent().inRoot()) {
+                    // 26-Aug-2024, tatu: [dataformats-text#495] Decorations?
+                    if (_nextColumnDecorator != null) {
+                        String nvl = _nextColumnDecorator.decorateNull(this);
+                        if (nvl != null) {
+                            _writer.write(_columnIndex(), nvl);
+                            return;
+                        }
+                    }
                     _writer.writeNull(_columnIndex());
                 }
 
@@ -813,6 +910,10 @@ public class CsvGenerator extends GeneratorBase
         if (!_skipValue) {
             if (!_arraySeparator.isEmpty()) {
                 _addToArray(String.valueOf(v));
+            // 26-Aug-2024, tatu: [dataformats-text#495] Decorations?
+            } else if (_nextColumnDecorator != null) {
+                _writer.write(_columnIndex(),
+                        _nextColumnDecorator.decorateValue(this, String.valueOf(v)));
             } else {
                 _writer.write(_columnIndex(), v);
             }
@@ -831,6 +932,10 @@ public class CsvGenerator extends GeneratorBase
         if (!_skipValue) {
             if (!_arraySeparator.isEmpty()) {
                 _addToArray(String.valueOf(v));
+            // 26-Aug-2024, tatu: [dataformats-text#495] Decorations?
+            } else if (_nextColumnDecorator != null) {
+                _writer.write(_columnIndex(),
+                        _nextColumnDecorator.decorateValue(this, String.valueOf(v)));
             } else {
                 _writer.write(_columnIndex(), v);
             }
@@ -848,8 +953,12 @@ public class CsvGenerator extends GeneratorBase
         if (!_skipValue) {
             if (!_arraySeparator.isEmpty()) {
                 _addToArray(String.valueOf(v));
+            // 26-Aug-2024, tatu: [dataformats-text#495] Decorations?
+            } else if (_nextColumnDecorator != null) {
+                _writer.write(_columnIndex(),
+                        _nextColumnDecorator.decorateValue(this, String.valueOf(v)));
             } else {
-                _writer.write(_columnIndex(), v.toString());
+                _writer.write(_columnIndex(), v);
 
             }
         }
@@ -862,6 +971,10 @@ public class CsvGenerator extends GeneratorBase
         if (!_skipValue) {
             if (!_arraySeparator.isEmpty()) {
                 _addToArray(String.valueOf(v));
+            // 26-Aug-2024, tatu: [dataformats-text#495] Decorations?
+            } else if (_nextColumnDecorator != null) {
+                _writer.write(_columnIndex(),
+                        _nextColumnDecorator.decorateValue(this, String.valueOf(v)));
             } else {
                 _writer.write(_columnIndex(), v);
             }
@@ -875,6 +988,10 @@ public class CsvGenerator extends GeneratorBase
         if (!_skipValue) {
             if (!_arraySeparator.isEmpty()) {
                 _addToArray(String.valueOf(v));
+            // 26-Aug-2024, tatu: [dataformats-text#495] Decorations?
+            } else if (_nextColumnDecorator != null) {
+                _writer.write(_columnIndex(),
+                        _nextColumnDecorator.decorateValue(this, String.valueOf(v)));
             } else {
                 _writer.write(_columnIndex(), v);
             }
@@ -890,12 +1007,16 @@ public class CsvGenerator extends GeneratorBase
         }
         _verifyValueWrite("write number");
         if (!_skipValue) {
-            String str = isEnabled(JsonGenerator.Feature.WRITE_BIGDECIMAL_AS_PLAIN)
-                    ? v.toPlainString() : v.toString();
+            boolean plain = isEnabled(JsonGenerator.Feature.WRITE_BIGDECIMAL_AS_PLAIN);
             if (!_arraySeparator.isEmpty()) {
-                _addToArray(String.valueOf(v));
+                _addToArray(plain ? v.toPlainString() : v.toString());
+            // 26-Aug-2024, tatu: [dataformats-text#495] Decorations?
+            } else if (_nextColumnDecorator != null) {
+                String numStr = plain ? v.toPlainString() : v.toString();
+                _writer.write(_columnIndex(),
+                        _nextColumnDecorator.decorateValue(this, numStr));
             } else {
-                _writer.write(_columnIndex(), str);
+                _writer.write(_columnIndex(), v, plain);
             }
         }
     }
@@ -911,6 +1032,10 @@ public class CsvGenerator extends GeneratorBase
         if (!_skipValue) {
             if (!_arraySeparator.isEmpty()) {
                 _addToArray(encodedValue);
+            // 26-Aug-2024, tatu: [dataformats-text#495] Decorations?
+            } else if (_nextColumnDecorator != null) {
+                _writer.write(_columnIndex(),
+                        _nextColumnDecorator.decorateValue(this, encodedValue));
             } else {
                 _writer.write(_columnIndex(), encodedValue);
             }
