@@ -2,12 +2,15 @@ package com.fasterxml.jackson.dataformat.csv.impl;
 
 import com.fasterxml.jackson.core.io.CharTypes;
 import com.fasterxml.jackson.core.io.IOContext;
+import com.fasterxml.jackson.core.io.NumberOutput;
 import com.fasterxml.jackson.dataformat.csv.CsvGenerator;
 import com.fasterxml.jackson.dataformat.csv.CsvGenerator.Feature;
 import com.fasterxml.jackson.dataformat.csv.CsvSchema;
 
 import java.io.IOException;
 import java.io.Writer;
+import java.math.BigDecimal;
+import java.math.BigInteger;
 import java.util.Arrays;
 
 /**
@@ -20,7 +23,8 @@ public class CsvEncoder
     // Default set of escaped characters (none)
     private static final int [] sOutputEscapes = new int[0];
 
-    final protected static char[] HEX_CHARS = CharTypes.copyHexChars();
+    // Upper case hex chars:
+    final protected static char[] HEX_CHARS = CharTypes.copyHexChars(true);
 
     /**
      * As an optimization we try coalescing short writes into
@@ -109,6 +113,9 @@ public class CsvEncoder
 
     protected boolean _cfgAlwaysQuoteEmptyStrings;
 
+    // @since 2.16
+    protected boolean _cfgAlwaysQuoteNumbers;
+
     protected boolean _cfgEscapeQuoteCharWithEscapeChar;
 
     /**
@@ -116,6 +123,11 @@ public class CsvEncoder
      */
     protected boolean _cfgEscapeControlCharWithEscapeChar;
 
+    /**
+     * @since 2.14
+     */
+    protected boolean _cfgUseFastDoubleWriter;
+
     protected final char _cfgQuoteCharEscapeChar;
 
     /**
@@ -150,7 +162,9 @@ public class CsvEncoder
      */
     protected int _lastBuffered = -1;
 
-    /*
+    // @since 2.17 (dataformats-csv#45)
+    protected boolean _trailingLFRemoved = false;
+
     /**********************************************************
     /* Output buffering, low-level
     /**********************************************************
@@ -193,14 +207,23 @@ public class CsvEncoder
     /**********************************************************
      */
 
+
+    @Deprecated //since 2.14
     public CsvEncoder(IOContext ctxt, int csvFeatures, Writer out, CsvSchema schema)
+    {
+        this(ctxt, csvFeatures, out, schema, false);
+    }
+
+    public CsvEncoder(IOContext ctxt, int csvFeatures, Writer out, CsvSchema schema, boolean useFastDoubleWriter)
     {
         _ioContext = ctxt;
         _csvFeatures = csvFeatures;
+        _cfgUseFastDoubleWriter = useFastDoubleWriter;
         _cfgOptimalQuoting = CsvGenerator.Feature.STRICT_CHECK_FOR_QUOTING.enabledIn(csvFeatures);
         _cfgIncludeMissingTail = !CsvGenerator.Feature.OMIT_MISSING_TAIL_COLUMNS.enabledIn(_csvFeatures);
         _cfgAlwaysQuoteStrings = CsvGenerator.Feature.ALWAYS_QUOTE_STRINGS.enabledIn(csvFeatures);
         _cfgAlwaysQuoteEmptyStrings = CsvGenerator.Feature.ALWAYS_QUOTE_EMPTY_STRINGS.enabledIn(csvFeatures);
+        _cfgAlwaysQuoteNumbers = CsvGenerator.Feature.ALWAYS_QUOTE_NUMBERS.enabledIn(csvFeatures);
         _cfgEscapeQuoteCharWithEscapeChar = CsvGenerator.Feature.ESCAPE_QUOTE_CHAR_WITH_ESCAPE_CHAR.enabledIn(csvFeatures);
         _cfgEscapeControlCharWithEscapeChar = Feature.ESCAPE_CONTROL_CHARS_WITH_ESCAPE_CHAR.enabledIn(csvFeatures);
 
@@ -235,10 +258,13 @@ public class CsvEncoder
     {
         _ioContext = base._ioContext;
         _csvFeatures = base._csvFeatures;
+        _cfgUseFastDoubleWriter = base._cfgUseFastDoubleWriter;
         _cfgOptimalQuoting = base._cfgOptimalQuoting;
         _cfgIncludeMissingTail = base._cfgIncludeMissingTail;
         _cfgAlwaysQuoteStrings = base._cfgAlwaysQuoteStrings;
         _cfgAlwaysQuoteEmptyStrings = base._cfgAlwaysQuoteEmptyStrings;
+        _cfgAlwaysQuoteNumbers = base._cfgAlwaysQuoteNumbers;
+
         _cfgEscapeQuoteCharWithEscapeChar = base._cfgEscapeQuoteCharWithEscapeChar;
         _cfgEscapeControlCharWithEscapeChar = base._cfgEscapeControlCharWithEscapeChar;
 
@@ -273,11 +299,11 @@ public class CsvEncoder
     {
         final char quoteEscapeChar;
 
-        if (_cfgEscapeQuoteCharWithEscapeChar && _cfgEscapeCharacter > 0) {
-            quoteEscapeChar = (char) _cfgEscapeCharacter;
+        if (escapeQuoteCharWithEscapeChar && escapeCharacter > 0) {
+            quoteEscapeChar = (char) escapeCharacter;
         }
-        else if (_cfgQuoteCharacter > 0) {
-            quoteEscapeChar = (char) _cfgQuoteCharacter;
+        else if (quoteCharacter > 0) {
+            quoteEscapeChar = (char) quoteCharacter;
         }
         else {
             quoteEscapeChar = '\\';
@@ -311,6 +337,7 @@ public class CsvEncoder
             _cfgIncludeMissingTail = !CsvGenerator.Feature.OMIT_MISSING_TAIL_COLUMNS.enabledIn(feat);
             _cfgAlwaysQuoteStrings = CsvGenerator.Feature.ALWAYS_QUOTE_STRINGS.enabledIn(feat);
             _cfgAlwaysQuoteEmptyStrings = CsvGenerator.Feature.ALWAYS_QUOTE_EMPTY_STRINGS.enabledIn(feat);
+            _cfgAlwaysQuoteNumbers = CsvGenerator.Feature.ALWAYS_QUOTE_NUMBERS.enabledIn(feat);
             _cfgEscapeQuoteCharWithEscapeChar = CsvGenerator.Feature.ESCAPE_QUOTE_CHAR_WITH_ESCAPE_CHAR.enabledIn(feat);
             _cfgEscapeControlCharWithEscapeChar = Feature.ESCAPE_CONTROL_CHARS_WITH_ESCAPE_CHAR.enabledIn(feat);
         }
@@ -389,14 +416,20 @@ public class CsvEncoder
         // easy case: all in order
         if (columnIndex == _nextColumnToWrite) {
             // inlined 'appendValue(int)'
-            // up to 10 digits and possible minus sign, leading comma
-            if ((_outputTail + 12) > _outputTail) {
+            // up to 10 digits and possible minus sign, leading comma, possible quotes
+            if ((_outputTail + 14) > _outputEnd) {
                 _flushBuffer();
             }
             if (_nextColumnToWrite > 0) {
                 _outputBuffer[_outputTail++] = _cfgColumnSeparator;
             }
+            if (_cfgAlwaysQuoteNumbers) {
+                _outputBuffer[_outputTail++] = (char) _cfgQuoteCharacter;
+            }
             _outputTail = NumberOutput.outputInt(value, _outputBuffer, _outputTail);
+            if (_cfgAlwaysQuoteNumbers) {
+                _outputBuffer[_outputTail++] = (char) _cfgQuoteCharacter;
+            }
             ++_nextColumnToWrite;
             return;
         }
@@ -408,20 +441,39 @@ public class CsvEncoder
         // easy case: all in order
         if (columnIndex == _nextColumnToWrite) {
             // inlined 'appendValue(int)'
-            // up to 20 digits, minus sign, leading comma
-            if ((_outputTail + 22) > _outputTail) {
+            // up to 20 digits, minus sign, leading comma, possible quotes
+            if ((_outputTail + 24) > _outputEnd) {
                 _flushBuffer();
             }
             if (_nextColumnToWrite > 0) {
                 _outputBuffer[_outputTail++] = _cfgColumnSeparator;
             }
+            if (_cfgAlwaysQuoteNumbers) {
+                _outputBuffer[_outputTail++] = (char) _cfgQuoteCharacter;
+            }
             _outputTail = NumberOutput.outputLong(value, _outputBuffer, _outputTail);
+            if (_cfgAlwaysQuoteNumbers) {
+                _outputBuffer[_outputTail++] = (char) _cfgQuoteCharacter;
+            }
             ++_nextColumnToWrite;
             return;
         }
         _buffer(columnIndex, BufferedValue.buffered(value));
     }
 
+    // @since 2.16
+    public final void write(int columnIndex, BigInteger value) throws IOException
+    {
+        // easy case: all in order
+        final String numStr = value.toString();
+        if (columnIndex == _nextColumnToWrite) {
+            appendNumberValue(numStr);
+            ++_nextColumnToWrite;
+            return;
+        }
+        _buffer(columnIndex, BufferedValue.bufferedNumber(numStr));
+    }
+    
     public final void write(int columnIndex, float value) throws IOException
     {
         // easy case: all in order
@@ -444,6 +496,20 @@ public class CsvEncoder
         _buffer(columnIndex, BufferedValue.buffered(value));
     }
 
+    // @since 2.16
+    public final void write(int columnIndex, BigDecimal value, boolean plain) throws IOException
+    {
+        final String numStr = plain ? value.toPlainString() : value.toString();
+
+        // easy case: all in order
+        if (columnIndex == _nextColumnToWrite) {
+            appendNumberValue(numStr);
+            ++_nextColumnToWrite;
+            return;
+        }
+        _buffer(columnIndex, BufferedValue.bufferedNumber(numStr));
+    }
+
     public final void write(int columnIndex, boolean value) throws IOException
     {
         // easy case: all in order
@@ -562,31 +628,43 @@ public class CsvEncoder
 
     protected void appendValue(int value) throws IOException
     {
-        // up to 10 digits and possible minus sign, leading comma
-        if ((_outputTail + 12) > _outputEnd) {
+        // up to 10 digits and possible minus sign, leading comma, possible quotes
+        if ((_outputTail + 14) > _outputEnd) {
             _flushBuffer();
         }
         if (_nextColumnToWrite > 0) {
             _outputBuffer[_outputTail++] = _cfgColumnSeparator;
         }
+        if (_cfgAlwaysQuoteNumbers) {
+            _outputBuffer[_outputTail++] = (char) _cfgQuoteCharacter;
+        }
         _outputTail = NumberOutput.outputInt(value, _outputBuffer, _outputTail);
+        if (_cfgAlwaysQuoteNumbers) {
+            _outputBuffer[_outputTail++] = (char) _cfgQuoteCharacter;
+        }
     }
 
     protected void appendValue(long value) throws IOException
     {
-        // up to 20 digits, minus sign, leading comma
-        if ((_outputTail + 22) > _outputEnd) {
+        // up to 20 digits, minus sign, leading comma, possible quotes
+        if ((_outputTail + 24) > _outputEnd) {
             _flushBuffer();
         }
         if (_nextColumnToWrite > 0) {
             _outputBuffer[_outputTail++] = _cfgColumnSeparator;
         }
+        if (_cfgAlwaysQuoteNumbers) {
+            _outputBuffer[_outputTail++] = (char) _cfgQuoteCharacter;
+        }
         _outputTail = NumberOutput.outputLong(value, _outputBuffer, _outputTail);
+        if (_cfgAlwaysQuoteNumbers) {
+            _outputBuffer[_outputTail++] = (char) _cfgQuoteCharacter;
+        }
     }
 
     protected void appendValue(float value) throws IOException
     {
-        String str = NumberOutput.toString(value);
+        String str = NumberOutput.toString(value, _cfgUseFastDoubleWriter);
         final int len = str.length();
         if ((_outputTail + len) >= _outputEnd) { // >= to include possible comma too
             _flushBuffer();
@@ -594,12 +672,12 @@ public class CsvEncoder
         if (_nextColumnToWrite > 0) {
             _outputBuffer[_outputTail++] = _cfgColumnSeparator;
         }
-        writeRaw(str);
+        writeNumber(str);
     }
 
     protected void appendValue(double value) throws IOException
     {
-        String str = NumberOutput.toString(value);
+        String str = NumberOutput.toString(value, _cfgUseFastDoubleWriter);
         final int len = str.length();
         if ((_outputTail + len) >= _outputEnd) { // >= to include possible comma too
             _flushBuffer();
@@ -607,7 +685,20 @@ public class CsvEncoder
         if (_nextColumnToWrite > 0) {
             _outputBuffer[_outputTail++] = _cfgColumnSeparator;
         }
-        writeRaw(str);
+        writeNumber(str);
+    }
+
+    // @since 2.16: pre-encoded BigInteger/BigDecimal value
+    protected void appendNumberValue(String numStr) throws IOException
+    {
+        // Same as "appendRawValue()", except may want quoting
+        if (_outputTail >= _outputEnd) {
+            _flushBuffer();
+        }
+        if (_nextColumnToWrite > 0) {
+            appendColumnSeparator();
+        }
+        writeNumber(numStr);
     }
 
     protected void appendValue(boolean value) throws IOException {
@@ -644,7 +735,7 @@ public class CsvEncoder
     /* Output methods, unprocessed ("raw")
     /**********************************************************
      */
-    
+
     public void writeRaw(String text) throws IOException
     {
         // Nothing to check, can just output as is
@@ -730,6 +821,25 @@ public class CsvEncoder
         _outputTail = len;
     }
 
+    // @since 2.16
+    private void writeNumber(String text) throws IOException
+    {
+        final int len = text.length();
+        if ((_outputTail + len + 2) > _outputEnd) {
+            _flushBuffer();
+        }
+
+        if (_cfgAlwaysQuoteNumbers) {
+            _outputBuffer[_outputTail++] = (char) _cfgQuoteCharacter;
+            text.getChars(0, len, _outputBuffer, _outputTail);
+            _outputTail += len;
+            _outputBuffer[_outputTail++] = (char) _cfgQuoteCharacter;
+        } else {
+            text.getChars(0, len, _outputBuffer, _outputTail);
+            _outputTail += len;
+        }
+    }
+
     /*
     /**********************************************************
     /* Output methods, with quoting and escaping
@@ -989,6 +1099,11 @@ public class CsvEncoder
 
     public void close(boolean autoClose, boolean flushStream) throws IOException
     {
+        // May need to remove the linefeed appended after the last row written
+        // (if not yet done)
+        if (!CsvGenerator.Feature.WRITE_LINEFEED_AFTER_LAST_ROW.enabledIn(_csvFeatures)) {
+            _removeTrailingLF();
+        }
         _flushBuffer();
         if (autoClose) {
             _out.close();
@@ -1000,6 +1115,15 @@ public class CsvEncoder
         _releaseBuffers();
     }
 
+    private void _removeTrailingLF() throws IOException {
+        if (!_trailingLFRemoved) {
+            _trailingLFRemoved = true;
+            // Remove trailing LF if (but only if) it appears to be in output
+            // buffer (may not be possible if `flush()` has been called)
+            _outputTail = Math.max(0, _outputTail - _cfgLineSeparatorLength);
+        }
+    }
+
     /*
     /**********************************************************
     /* Internal methods
