@@ -4,15 +4,16 @@ import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.util.*;
 
-import com.fasterxml.jackson.annotation.JsonPropertyOrder;
+import org.junit.jupiter.api.Test;
 
+import com.fasterxml.jackson.annotation.JsonPropertyOrder;
 import com.fasterxml.jackson.core.JsonProcessingException;
 import com.fasterxml.jackson.core.JsonToken;
-
-import com.fasterxml.jackson.databind.*;
+import com.fasterxml.jackson.databind.MappingIterator;
+import com.fasterxml.jackson.databind.ObjectReader;
 import com.fasterxml.jackson.dataformat.csv.*;
 
-import static org.junit.Assert.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.*;
 
 public class BasicCSVParserTest extends ModuleTestBase
 {
@@ -39,6 +40,7 @@ public class BasicCSVParserTest extends ModuleTestBase
 
     final CsvMapper MAPPER = mapperForCsv();
 
+    @Test
     public void testSimpleExplicit() throws Exception
     {
         ObjectReader r = MAPPER.reader(SIMPLE_SCHEMA);
@@ -54,7 +56,7 @@ public class BasicCSVParserTest extends ModuleTestBase
         if (useBytes) {
             user = r.readValue(INPUT);
         } else {
-            user = r.readValue(INPUT.getBytes("UTF-8"));
+            user = r.readValue(utf8(INPUT));
         }
         assertEquals("Bob", user.firstName);
         assertEquals("Robertson", user.lastName);
@@ -63,6 +65,7 @@ public class BasicCSVParserTest extends ModuleTestBase
         assertArrayEquals(new byte[]{1, 2, 3, 4, 5}, user.getUserImage());
     }
 
+    @Test
     public void testSimpleExplicitWithBOM() throws Exception {
         ObjectReader r = MAPPER.reader(SIMPLE_SCHEMA);
         r = r.forType(FiveMinuteUser.class);
@@ -72,7 +75,7 @@ public class BasicCSVParserTest extends ModuleTestBase
 
         // first, UTF-8 BOM:
         b.write(new byte[]{(byte) 0xEF, (byte) 0xBB, (byte) 0xBF});
-        b.write("Bob,Robertson,MALE,AQIDBAU=,false\n".getBytes("UTF-8"));
+        b.write(utf8("Bob,Robertson,MALE,AQIDBAU=,false\n"));
         b.close();
 
         user = r.readValue(b.toByteArray());
@@ -87,6 +90,7 @@ public class BasicCSVParserTest extends ModuleTestBase
         assertArrayEquals(new byte[]{1, 2, 3, 4, 5}, user.getUserImage());
     }
 
+    @Test
     public void testSimpleWithAutoSchema() throws Exception {
         CsvSchema schema = MAPPER.schemaFor(FiveMinuteUser.class);
         // NOTE: order different from above test (as per POJO def!)
@@ -102,6 +106,7 @@ public class BasicCSVParserTest extends ModuleTestBase
      * Test to verify that we can mix "untyped" access as Maps
      * with schema information...
      */
+    @Test
     public void testSimpleAsMaps() throws Exception {
         CsvSchema schema = MAPPER.schemaFor(FiveMinuteUser.class);
         MappingIterator<Map<?, ?>> it = MAPPER.reader(schema).forType(Map.class).readValues(
@@ -121,6 +126,7 @@ public class BasicCSVParserTest extends ModuleTestBase
     }
 
     // Test for [Issue#10]
+    @Test
     public void testMapsWithLinefeeds() throws Exception {
         _testMapsWithLinefeeds(false);
         _testMapsWithLinefeeds(true);
@@ -139,7 +145,7 @@ public class BasicCSVParserTest extends ModuleTestBase
         MappingIterator<Map<String, String>> mi;
 
         if (useBytes) {
-            mi = or.readValues(CSV.getBytes("UTF-8"));
+            mi = or.readValues(utf8(CSV));
         } else {
             mi = or.readValues(CSV);
         }
@@ -178,6 +184,7 @@ public class BasicCSVParserTest extends ModuleTestBase
     }
 
     // [dataformat-csv#12]
+    @Test
     public void testEmptyHandlingForInteger() throws Exception {
         CsvSchema schema = MAPPER.typedSchemaFor(Point.class).withoutHeader();
 
@@ -188,6 +195,7 @@ public class BasicCSVParserTest extends ModuleTestBase
         assertNull(result.z);
     }
 
+    @Test
     public void testStringNullHandlingForInteger() throws Exception {
         CsvSchema schema = MAPPER.typedSchemaFor(Point.class).withoutHeader();
 
@@ -198,6 +206,7 @@ public class BasicCSVParserTest extends ModuleTestBase
         assertNull(result.z);
     }
 
+    @Test
     public void testLeadingZeroesForInts() throws Exception {
         CsvSchema schema = MAPPER.typedSchemaFor(Point.class).withoutHeader();
         Point result = MAPPER.readerFor(Point.class).with(schema).readValue("012,\"090\",\n");
@@ -207,6 +216,7 @@ public class BasicCSVParserTest extends ModuleTestBase
     }
 
     // [dataformat-csv#41]
+    @Test
     public void testIncorrectDups41() throws Exception {
         final String INPUT = "\"foo\",\"bar\",\"foo\"";
         CsvSchema schema = CsvSchema.builder().addColumn("Col1").addColumn("Col2")
@@ -228,6 +238,7 @@ public class BasicCSVParserTest extends ModuleTestBase
     }
 
     // for [dataformat-csv#89]
+    @Test
     public void testColumnReordering() throws IOException {
         CsvFactory factory = new CsvFactory();
         String CSV = "b,a,c\nvb,va,vc\n";
@@ -251,15 +262,20 @@ public class BasicCSVParserTest extends ModuleTestBase
         parser.setSchema(schemaWithReordering);
         assertEquals(JsonToken.START_OBJECT, parser.nextToken());
         assertEquals(JsonToken.FIELD_NAME, parser.nextToken());
-        assertEquals("b", parser.getCurrentName());
+        assertEquals("b", parser.currentName());
+        assertEquals("b", parser.getText());
+        assertEquals("b", parser.getValueAsString());
+        assertEquals("b", parser.getValueAsString("x"));
         assertEquals(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("vb", parser.getValueAsString());
+        assertEquals("vb", parser.getValueAsString());
+        assertEquals("vb", parser.getValueAsString("x"));
         assertEquals(JsonToken.FIELD_NAME, parser.nextToken());
-        assertEquals("a",parser.getCurrentName());
+        assertEquals("a",parser.currentName());
         assertEquals(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("va", parser.getValueAsString());
         assertEquals(JsonToken.FIELD_NAME, parser.nextToken());
-        assertEquals("c", parser.getCurrentName());
+        assertEquals("c", parser.currentName());
         assertEquals(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("vc", parser.getValueAsString());
         assertEquals(JsonToken.END_OBJECT, parser.nextToken());
@@ -275,15 +291,15 @@ public class BasicCSVParserTest extends ModuleTestBase
         parser.setSchema(schemaWithoutReordering);
         assertEquals(JsonToken.START_OBJECT, parser.nextToken());
         assertEquals(JsonToken.FIELD_NAME, parser.nextToken());
-        assertEquals("a", parser.getCurrentName());
+        assertEquals("a", parser.currentName());
         assertEquals(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("vb", parser.getValueAsString());
         assertEquals(JsonToken.FIELD_NAME, parser.nextToken());
-        assertEquals("b", parser.getCurrentName());
+        assertEquals("b", parser.currentName());
         assertEquals(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("va", parser.getValueAsString());
         assertEquals(JsonToken.FIELD_NAME, parser.nextToken());
-        assertEquals("c", parser.getCurrentName());
+        assertEquals("c", parser.currentName());
         assertEquals(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("vc", parser.getValueAsString());
         assertEquals(JsonToken.END_OBJECT, parser.nextToken());
@@ -301,15 +317,15 @@ public class BasicCSVParserTest extends ModuleTestBase
         parser.setSchema(schemaWithoutHeader);
         assertEquals(JsonToken.START_OBJECT, parser.nextToken());
         assertEquals(JsonToken.FIELD_NAME, parser.nextToken());
-        assertEquals("a", parser.getCurrentName());
+        assertEquals("a", parser.currentName());
         assertEquals(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("vb", parser.getValueAsString());
         assertEquals(JsonToken.FIELD_NAME, parser.nextToken());
-        assertEquals("b", parser.getCurrentName());
+        assertEquals("b", parser.currentName());
         assertEquals(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("va", parser.getValueAsString());
         assertEquals(JsonToken.FIELD_NAME, parser.nextToken());
-        assertEquals("c", parser.getCurrentName());
+        assertEquals("c", parser.currentName());
         assertEquals(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("vc", parser.getValueAsString());
         assertEquals(JsonToken.END_OBJECT, parser.nextToken());
@@ -328,21 +344,22 @@ public class BasicCSVParserTest extends ModuleTestBase
         parser.setSchema(emptySchema);
         assertEquals(JsonToken.START_OBJECT, parser.nextToken());
         assertEquals(JsonToken.FIELD_NAME, parser.nextToken());
-        assertEquals("b", parser.getCurrentName());
+        assertEquals("b", parser.currentName());
         assertEquals(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("vb", parser.getValueAsString());
         assertEquals(JsonToken.FIELD_NAME, parser.nextToken());
-        assertEquals("a", parser.getCurrentName());
+        assertEquals("a", parser.currentName());
         assertEquals(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("va", parser.getValueAsString());
         assertEquals(JsonToken.FIELD_NAME, parser.nextToken());
-        assertEquals("c", parser.getCurrentName());
+        assertEquals("c", parser.currentName());
         assertEquals(JsonToken.VALUE_STRING, parser.nextToken());
         assertEquals("vc", parser.getValueAsString());
         assertEquals(JsonToken.END_OBJECT, parser.nextToken());
         parser.close();
     }
 
+    @Test
     public void testColumnFailsOnOutOfOrder() throws IOException {
         CsvFactory factory = new CsvFactory();
         String CSV = "b,a,c\nvb,va,vc\n";
@@ -368,6 +385,7 @@ public class BasicCSVParserTest extends ModuleTestBase
         parser.close();
     }
 
+    @Test
     public void testColumnFailsOnTooFew() throws IOException {
         CsvFactory factory = new CsvFactory();
         String CSV = "a,b\nvb,va,vc\n";
@@ -393,6 +411,7 @@ public class BasicCSVParserTest extends ModuleTestBase
         parser.close();
     }
 
+    @Test
     public void testColumnFailsOnTooMany() throws IOException {
         CsvFactory factory = new CsvFactory();
         String CSV = "a,b,c,d\nvb,va,vc\n";
@@ -413,11 +432,12 @@ public class BasicCSVParserTest extends ModuleTestBase
             parser.nextToken();
             fail("Should have failed");
         } catch (JsonProcessingException e) {
-            verifyException(e, "Extra header d");
+            verifyException(e, "Extra header column \"d\"");
         }
         parser.close();
     }
 
+    @Test
     public void testStrictColumnReturnsExpectedData() throws IOException {
         CsvSchema schema = MAPPER.schemaFor(Point.class).withHeader().withStrictHeaders(true);
 
