@@ -1,9 +1,13 @@
 package com.fasterxml.jackson.dataformat.csv.ser;
 
-import com.fasterxml.jackson.annotation.*;
+import org.junit.jupiter.api.Test;
 
+import com.fasterxml.jackson.annotation.JsonPropertyOrder;
+import com.fasterxml.jackson.annotation.JsonUnwrapped;
 import com.fasterxml.jackson.dataformat.csv.*;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 public class UnwrappedWriteTest extends ModuleTestBase
 {
     @JsonPropertyOrder({ "f1", "f2", "f3" })
@@ -22,6 +26,7 @@ public class UnwrappedWriteTest extends ModuleTestBase
     }
 
     // for [dataformat-csv#125]
+    @Test
     public void testWriteUnwrapped() throws Exception
     {
         CsvMapper mapper = mapperForCsv();
