@@ -1,11 +1,16 @@
 package com.fasterxml.jackson.dataformat.javaprop;
 
+import org.junit.jupiter.api.Test;
+
 import com.fasterxml.jackson.databind.ObjectMapper;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 public class CustomSeparatorsTest extends ModuleTestBase
 {
     private final ObjectMapper MAPPER = newPropertiesMapper();
 
+    @Test
     public void testCustomPathSeparator() throws Exception
     {
         JavaPropsSchema schema = JavaPropsSchema.emptySchema()
