@@ -1,8 +1,14 @@
 package com.fasterxml.jackson.dataformat.javaprop;
 
+import org.junit.jupiter.api.Test;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+
 public class SchemaConstructionTest extends ModuleTestBase
 {
     // Tests to verify stickiness of settings
+    @Test
     public void testMutantFactories()
     {
         JavaPropsSchema empty = JavaPropsSchema.emptySchema();
