@@ -2,9 +2,6 @@ package com.fasterxml.jackson.dataformat.yaml;
 
 import java.io.*;
 import java.net.URL;
-import java.nio.charset.Charset;
-
-import org.yaml.snakeyaml.DumperOptions;
 
 import com.fasterxml.jackson.core.*;
 import com.fasterxml.jackson.core.format.InputAccessor;
@@ -12,13 +9,14 @@ import com.fasterxml.jackson.core.format.MatchStrength;
 import com.fasterxml.jackson.core.io.IOContext;
 import com.fasterxml.jackson.dataformat.yaml.util.StringQuotingChecker;
 
+import org.yaml.snakeyaml.DumperOptions;
+import org.yaml.snakeyaml.LoaderOptions;
+
 @SuppressWarnings("resource")
 public class YAMLFactory extends JsonFactory
 {
 	private static final long serialVersionUID = 1L;
 
-	protected final static Charset UTF8 = Charset.forName("UTF-8");
-
 	/**
      * Name used to identify YAML format.
      * (and returned by {@link #getFormatName()}
@@ -47,10 +45,10 @@ public class YAMLFactory extends JsonFactory
     /**********************************************************************
      */
 
-    protected int _yamlParserFeatures = DEFAULT_YAML_PARSER_FEATURE_FLAGS;
-
     protected int _yamlGeneratorFeatures = DEFAULT_YAML_GENERATOR_FEATURE_FLAGS;
 
+    protected int _yamlParserFeatures = DEFAULT_YAML_PARSER_FEATURE_FLAGS;
+
     /**
      * YAML version for underlying generator to follow, if specified.
      *
@@ -66,6 +64,40 @@ public class YAMLFactory extends JsonFactory
      */
     protected final StringQuotingChecker _quotingChecker;
 
+    /**
+     * Configuration for underlying parser to follow, if specified;
+     * left as {@code null} for backwards compatibility (which means
+     * whatever default settings {@code SnakeYAML} deems best).
+     * <p>
+     *     If you need to support parsing YAML files that are larger than 3Mb,
+     *     it is recommended that you provide a LoaderOptions instance where
+     *     you set the Codepoint Limit to a larger value than its 3Mb default.
+     * </p>
+     *
+     * @since 2.14
+     */
+    protected final LoaderOptions _loaderOptions;
+
+    /**
+     * Configuration for underlying generator to follow, if specified;
+     * left as {@code null} for backwards compatibility (which means
+     * the dumper options are derived based on {@link YAMLGenerator.Feature}s).
+     * <p>
+     *     These {@link YAMLGenerator.Feature}s are ignored if you provide your own DumperOptions:
+     *     <ul>
+     *         <li>{@code YAMLGenerator.Feature.ALLOW_LONG_KEYS}</li>
+     *         <li>{@code YAMLGenerator.Feature.CANONICAL_OUTPUT}</li>
+     *         <li>{@code YAMLGenerator.Feature.INDENT_ARRAYS}</li>
+     *         <li>{@code YAMLGenerator.Feature.INDENT_ARRAYS_WITH_INDICATOR}</li>
+     *         <li>{@code YAMLGenerator.Feature.SPLIT_LINES}</li>
+     *         <li>{@code YAMLGenerator.Feature.USE_PLATFORM_LINE_BREAKS}</li>
+     *     </ul>
+     * </p>
+     *
+     * @since 2.14
+     */
+    protected final DumperOptions _dumperOptions;
+
     /*
     /**********************************************************************
     /* Factory construction, configuration
@@ -87,13 +119,15 @@ public class YAMLFactory extends JsonFactory
     public YAMLFactory(ObjectCodec oc)
     {
         super(oc);
-        _yamlParserFeatures = DEFAULT_YAML_PARSER_FEATURE_FLAGS;
         _yamlGeneratorFeatures = DEFAULT_YAML_GENERATOR_FEATURE_FLAGS;
+        _yamlParserFeatures = DEFAULT_YAML_PARSER_FEATURE_FLAGS;
         // 26-Jul-2013, tatu: Seems like we should force output as 1.1 but
         //   that adds version declaration which looks ugly...
         //_version = DumperOptions.Version.V1_1;
         _version = null;
         _quotingChecker = StringQuotingChecker.Default.instance();
+        _loaderOptions = null;
+        _dumperOptions = null;
     }
 
     /**
@@ -102,10 +136,12 @@ public class YAMLFactory extends JsonFactory
     public YAMLFactory(YAMLFactory src, ObjectCodec oc)
     {
         super(src, oc);
-        _yamlParserFeatures = src._yamlParserFeatures;
         _yamlGeneratorFeatures = src._yamlGeneratorFeatures;
+        _yamlParserFeatures = src._yamlParserFeatures;
         _version = src._version;
         _quotingChecker = src._quotingChecker;
+        _loaderOptions = src._loaderOptions;
+        _dumperOptions = src._dumperOptions;
     }
 
     /**
@@ -117,8 +153,11 @@ public class YAMLFactory extends JsonFactory
     {
         super(b, false);
         _yamlGeneratorFeatures = b.formatGeneratorFeaturesMask();
+        _yamlParserFeatures = b.formatParserFeaturesMask();
         _version = b.yamlVersionToWrite();
         _quotingChecker = b.stringQuotingChecker();
+        _loaderOptions = b.loaderOptions();
+        _dumperOptions = b.dumperOptions();
     }
 
     @Override
@@ -237,56 +276,6 @@ public class YAMLFactory extends JsonFactory
         }
         return MatchStrength.INCONCLUSIVE;
     }
-    
-    /*
-    /**********************************************************
-    /* Configuration, parser settings
-    /**********************************************************
-     */
-
-    /**
-     * Method for enabling or disabling specified parser feature
-     * (check {@link YAMLParser.Feature} for list of features)
-     */
-    public final YAMLFactory configure(YAMLParser.Feature f, boolean state)
-    {
-        if (state) {
-            enable(f);
-        } else {
-            disable(f);
-        }
-        return this;
-    }
-
-    /**
-     * Method for enabling specified parser feature
-     * (check {@link YAMLParser.Feature} for list of features)
-     */
-    public YAMLFactory enable(YAMLParser.Feature f) {
-        _yamlParserFeatures |= f.getMask();
-        return this;
-    }
-
-    /**
-     * Method for disabling specified parser features
-     * (check {@link YAMLParser.Feature} for list of features)
-     */
-    public YAMLFactory disable(YAMLParser.Feature f) {
-        _yamlParserFeatures &= ~f.getMask();
-        return this;
-    }
-
-    /**
-     * Checked whether specified parser feature is enabled.
-     */
-    public final boolean isEnabled(YAMLParser.Feature f) {
-        return (_yamlParserFeatures & f.getMask()) != 0;
-    }
-
-    @Override
-    public int getFormatParserFeatures() {
-        return _yamlParserFeatures;
-    }
 
     /*
     /**********************************************************
@@ -337,6 +326,56 @@ public class YAMLFactory extends JsonFactory
         return _yamlGeneratorFeatures;
     }
 
+    /*
+    /**********************************************************
+    /* Configuration, parser settings
+    /**********************************************************
+     */
+
+    /**
+     * Method for enabling or disabling specified parser feature
+     * (check {@link YAMLParser.Feature} for list of features)
+     */
+    public final YAMLFactory configure(YAMLParser.Feature f, boolean state)
+    {
+        if (state) {
+            enable(f);
+        } else {
+            disable(f);
+        }
+        return this;
+    }
+
+    /**
+     * Method for enabling specified parser feature
+     * (check {@link YAMLParser.Feature} for list of features)
+     */
+    public YAMLFactory enable(YAMLParser.Feature f) {
+        _yamlParserFeatures |= f.getMask();
+        return this;
+    }
+
+    /**
+     * Method for disabling specified parser features
+     * (check {@link YAMLParser.Feature} for list of features)
+     */
+    public YAMLFactory disable(YAMLParser.Feature f) {
+        _yamlParserFeatures &= ~f.getMask();
+        return this;
+    }
+
+    /**
+     * Checked whether specified parser feature is enabled.
+     */
+    public final boolean isEnabled(YAMLParser.Feature f) {
+        return (_yamlParserFeatures & f.getMask()) != 0;
+    }
+
+    @Override
+    public int getFormatParserFeatures() {
+        return _yamlParserFeatures;
+    }
+
     /*
     /**********************************************************
     /* Overridden parser factory methods
@@ -354,6 +393,7 @@ public class YAMLFactory extends JsonFactory
         return _createParser(_decorate(new FileInputStream(f), ctxt), ctxt);
     }
 
+    @Deprecated // since 2.20
     @Override
     public YAMLParser createParser(URL url) throws IOException
     {
@@ -410,7 +450,7 @@ public class YAMLFactory extends JsonFactory
         }
         return _createParser(data, offset, len, ctxt);
     }
-    
+
     /*
     /**********************************************************
     /* Overridden generator factory methods (2.1)
@@ -462,37 +502,40 @@ public class YAMLFactory extends JsonFactory
 
     @Override
     protected YAMLParser _createParser(InputStream in, IOContext ctxt) throws IOException {
-        return new YAMLParser(ctxt, _getBufferRecycler(), _parserFeatures, _yamlParserFeatures,
-                _objectCodec, _createReader(in, null, ctxt));
+        return new YAMLParser(ctxt, _parserFeatures, _yamlParserFeatures,
+                _loaderOptions, _objectCodec, _createReader(in, null, ctxt));
     }
 
     @Override
     protected YAMLParser _createParser(Reader r, IOContext ctxt) throws IOException {
-        return new YAMLParser(ctxt, _getBufferRecycler(), _parserFeatures, _yamlParserFeatures,
-                _objectCodec, r);
+        return new YAMLParser(ctxt, _parserFeatures, _yamlParserFeatures,
+                _loaderOptions, _objectCodec, r);
     }
 
     // since 2.4
     @Override
     protected YAMLParser _createParser(char[] data, int offset, int len, IOContext ctxt,
             boolean recyclable) throws IOException {
-        return new YAMLParser(ctxt, _getBufferRecycler(), _parserFeatures, _yamlParserFeatures,
-                _objectCodec, new CharArrayReader(data, offset, len));
+        return new YAMLParser(ctxt, _parserFeatures, _yamlParserFeatures,
+                _loaderOptions, _objectCodec, new CharArrayReader(data, offset, len));
     }
 
     @Override
     protected YAMLParser _createParser(byte[] data, int offset, int len, IOContext ctxt) throws IOException {
-        return new YAMLParser(ctxt, _getBufferRecycler(), _parserFeatures, _yamlParserFeatures,
-                _objectCodec, _createReader(data, offset, len, null, ctxt));
+        return new YAMLParser(ctxt, _parserFeatures, _yamlParserFeatures,
+                _loaderOptions, _objectCodec, _createReader(data, offset, len, null, ctxt));
     }
 
     @Override
     protected YAMLGenerator _createGenerator(Writer out, IOContext ctxt) throws IOException {
         int feats = _yamlGeneratorFeatures;
-        YAMLGenerator gen = new YAMLGenerator(ctxt, _generatorFeatures, feats,
-                _quotingChecker, _objectCodec, out, _version);
-        // any other initializations? No?
-        return gen;
+        if (_dumperOptions == null) {
+            return new YAMLGenerator(ctxt, _generatorFeatures, feats,
+                    _quotingChecker, _objectCodec, out, _version);
+        } else {
+            return new YAMLGenerator(ctxt, _generatorFeatures, feats,
+                    _quotingChecker, _objectCodec, out, _dumperOptions);
+        }
     }
 
     @Override
