@@ -58,15 +58,22 @@ public class YAMLGenerator extends GeneratorBase
 
         /**
          * Do we try to force so-called canonical output or not.
+         * <p>
+         *     Ignored if you provide your own {@code DumperOptions}.
+         * </p>
          */
         CANONICAL_OUTPUT(false),
 
         /**
          * Options passed to SnakeYAML that determines whether longer textual content
          * gets automatically split into multiple lines or not.
-         *<p>
-         * Feature is enabled by default to conform to SnakeYAML defaults as well as
-         * backwards compatibility with 2.5 and earlier versions.
+         * <p>
+         *     Feature is enabled by default to conform to SnakeYAML defaults as well as
+         *     backwards compatibility with 2.5 and earlier versions.
+         * </p>
+         * <p>
+         *     Ignored if you provide your own {@code DumperOptions}.
+         * </p>
          *
          * @since 2.6
          */
@@ -75,10 +82,11 @@ public class YAMLGenerator extends GeneratorBase
         /**
          * Whether strings will be rendered without quotes (true) or
          * with quotes (false, default).
-         *<p>
-         * Minimized quote usage makes for more human readable output; however, content is
-         * limited to printable characters according to the rules of
-         * <a href="http://www.yaml.org/spec/1.2/spec.html#style/block/literal">literal block style</a>.
+         * <p>
+         *     Minimized quote usage makes for more human readable output; however, content is
+         *     limited to printable characters according to the rules of
+         *     <a href="http://www.yaml.org/spec/1.2/spec.html#style/block/literal">literal block style</a>.
+         * </p>
          *
          * @since 2.7
          */
@@ -87,10 +95,11 @@ public class YAMLGenerator extends GeneratorBase
         /**
          * Whether numbers stored as strings will be rendered with quotes (true) or
          * without quotes (false, default) when MINIMIZE_QUOTES is enabled.
-         *<p>
-         * Minimized quote usage makes for more human readable output; however, content is
-         * limited to printable characters according to the rules of
-         * <a href="http://www.yaml.org/spec/1.2/spec.html#style/block/literal">literal block style</a>.
+         * <p>
+         *     Minimized quote usage makes for more human readable output; however, content is
+         *     limited to printable characters according to the rules of
+         *     <a href="http://www.yaml.org/spec/1.2/spec.html#style/block/literal">literal block style</a>.
+         * </p>
          *
          * @since 2.8.2
          */
@@ -101,8 +110,9 @@ public class YAMLGenerator extends GeneratorBase
          * <a href="http://www.yaml.org/spec/1.2/spec.html#style/block/literal">literal block style</a>
          * should be used. This automatically enabled when {@link #MINIMIZE_QUOTES} is set.
          * <p>
-         * The content of such strings is limited to printable characters according to the rules of
-         * <a href="http://www.yaml.org/spec/1.2/spec.html#style/block/literal">literal block style</a>.
+         *     The content of such strings is limited to printable characters according to the rules of
+         *     <a href="http://www.yaml.org/spec/1.2/spec.html#style/block/literal">literal block style</a>.
+         * </p>
          *
          * @since 2.9
          */
@@ -111,8 +121,12 @@ public class YAMLGenerator extends GeneratorBase
         /**
          * Feature enabling of which adds indentation for array entry generation
          * (default indentation being 2 spaces).
-         *<p>
-         * Default value is {@code false} for backwards compatibility
+         * <p>
+         *     Default value is {@code false} for backwards compatibility
+         * </p>
+         * <p>
+         *     Ignored if you provide your own {@code DumperOptions}.
+         * </p>
          *
          * @since 2.9
          */
@@ -120,8 +134,12 @@ public class YAMLGenerator extends GeneratorBase
         /**
          * Feature enabling of which adds indentation with indicator for array entry generation
          * (default indentation being 2 spaces).
-         *<p>
-         * Default value is {@code false} for backwards compatibility
+         * <p>
+         *     Default value is {@code false} for backwards compatibility
+         * </p>
+         * <p>
+         *     Ignored if you provide your own {@code DumperOptions}.
+         * </p>
          *
          * @since 2.12
          */
@@ -132,11 +150,32 @@ public class YAMLGenerator extends GeneratorBase
          * serialization should be same as what the default is for current platform.
          * If disabled, Unix linefeed ({@code \n}) will be used.
          * <p>
-         * Default value is {@code false} for backwards compatibility.
+         *     Default value is {@code false} for backwards compatibility
+         * </p>
+         * <p>
+         *     Ignored if you provide your own {@code DumperOptions}.
+         * </p>
          *
          * @since 2.9.6
          */
         USE_PLATFORM_LINE_BREAKS(false),
+
+        /**
+         * Option passed to SnakeYAML to allows writing key longer that 128 characters
+         * (up to 1024 characters).
+         * If disabled, the max key length is left as 128 characters: longer names
+         * are truncated. If enabled, limit is raised to 1024 characters.
+         * <p>
+         *     Default value is {@code false} for backwards-compatibility (same as behavior
+         *     before this feature was added).
+         * </p>
+         * <p>
+         *     Ignored if you provide your own {@code DumperOptions}.
+         * </p>
+         * 
+         * @since 2.14
+         */
+        ALLOW_LONG_KEYS(false),
         ;
 
         protected final boolean _defaultState;
@@ -178,7 +217,7 @@ public class YAMLGenerator extends GeneratorBase
 
     protected final static long MIN_INT_AS_LONG = (long) Integer.MIN_VALUE;
     protected final static long MAX_INT_AS_LONG = (long) Integer.MAX_VALUE;
-    protected final static Pattern PLAIN_NUMBER_P = Pattern.compile("-?[0-9]*(\\.[0-9]*)?");
+    protected final static Pattern PLAIN_NUMBER_P = Pattern.compile("[+-]?[0-9]*(\\.[0-9]*)?");
     protected final static String TAG_BINARY = Tag.BINARY.toString();
 
     /*
@@ -187,7 +226,10 @@ public class YAMLGenerator extends GeneratorBase
     /**********************************************************************
      */
 
-    final protected IOContext _ioContext;
+    /**
+     * @since 2.16
+     */
+    protected final StreamWriteConstraints _streamWriteConstraints;
 
     /**
      * Bit flag composed of bits that indicate which
@@ -254,8 +296,8 @@ public class YAMLGenerator extends GeneratorBase
             org.yaml.snakeyaml.DumperOptions.Version version)
         throws IOException
     {
-        super(jsonFeatures, codec);
-        _ioContext = ctxt;
+        super(jsonFeatures, codec, ctxt);
+        _streamWriteConstraints = ctxt.streamWriteConstraints();
         _formatFeatures = yamlFeatures;
         _quotingChecker = (quotingChecker == null)
                 ? StringQuotingChecker.Default.instance() : quotingChecker;
@@ -270,6 +312,30 @@ public class YAMLGenerator extends GeneratorBase
         _emitStartDocument();
     }
 
+    /**
+     * @since 2.14
+     */
+    public YAMLGenerator(IOContext ctxt, int jsonFeatures, int yamlFeatures,
+                         StringQuotingChecker quotingChecker,
+                         ObjectCodec codec, Writer out,
+                         org.yaml.snakeyaml.DumperOptions dumperOptions)
+            throws IOException
+    {
+        super(jsonFeatures, codec, ctxt);
+        _streamWriteConstraints = ctxt.streamWriteConstraints();
+        _formatFeatures = yamlFeatures;
+        _quotingChecker = (quotingChecker == null)
+                ? StringQuotingChecker.Default.instance() : quotingChecker;
+        _writer = out;
+        _docVersion = dumperOptions.getVersion();
+        _outputOptions = dumperOptions;
+
+        _emitter = new Emitter(_writer, _outputOptions);
+        // should we start output now, or try to defer?
+        _emit(new StreamStartEvent(null, null));
+        _emitStartDocument();
+    }
+
     @Deprecated // since 2.12
     public YAMLGenerator(IOContext ctxt, int jsonFeatures, int yamlFeatures,
             ObjectCodec codec, Writer out,
@@ -310,9 +376,18 @@ public class YAMLGenerator extends GeneratorBase
         if (Feature.USE_PLATFORM_LINE_BREAKS.enabledIn(_formatFeatures)) {
             opt.setLineBreak(DumperOptions.LineBreak.getPlatformLineBreak());
         }
+
+        if (Feature.ALLOW_LONG_KEYS.enabledIn(_formatFeatures)) {
+            opt.setMaxSimpleKeyLength(1024);
+        }
         return opt;
     }
 
+    @Override
+    public StreamWriteConstraints streamWriteConstraints() {
+        return _streamWriteConstraints;
+    }
+
     /*
     /**********************************************************************
     /* Versioned
@@ -488,7 +563,6 @@ public class YAMLGenerator extends GeneratorBase
 
             _emitEndDocument();
             _emit(new StreamEndEvent(null, null));
-            super.close();
 
             /* 25-Nov-2008, tatus: As per [JACKSON-16] we are not to call close()
              *   on the underlying Reader, unless we "own" it, or auto-closing
@@ -504,6 +578,7 @@ public class YAMLGenerator extends GeneratorBase
                     _writer.flush();
                 }
             }
+            super.close();
         }
     }
 
@@ -518,6 +593,7 @@ public class YAMLGenerator extends GeneratorBase
     {
         _verifyValueWrite("start an array");
         _writeContext = _writeContext.createChildArrayContext();
+        _streamWriteConstraints.validateNestingDepth(_writeContext.getNestingDepth());
         FlowStyle style = _outputOptions.getDefaultFlowStyle();
         String yamlTag = _typeId;
         boolean implicit = (yamlTag == null);
@@ -546,6 +622,7 @@ public class YAMLGenerator extends GeneratorBase
     {
         _verifyValueWrite("start an object");
         _writeContext = _writeContext.createChildObjectContext();
+        _streamWriteConstraints.validateNestingDepth(_writeContext.getNestingDepth());
         FlowStyle style = _outputOptions.getDefaultFlowStyle();
         String yamlTag = _typeId;
         boolean implicit = (yamlTag == null);
@@ -576,7 +653,7 @@ public class YAMLGenerator extends GeneratorBase
      */
 
     @Override
-    public void writeString(String text) throws IOException,JsonGenerationException
+    public void writeString(String text) throws IOException, JsonGenerationException
     {
         if (text == null) {
             writeNull();
@@ -889,8 +966,7 @@ public class YAMLGenerator extends GeneratorBase
         if (b64variant == Base64Variants.getDefaultVariant()) {
             b64variant = Base64Variants.MIME;
         }
-        final String lf = _lf();
-        String encoded = _base64encode(b64variant, data, lf);
+        String encoded = b64variant.encode(data, false, _lf());
         _emit(new ScalarEvent(null, TAG_BINARY, EXPLICIT_TAGS, encoded,
                 null, null, STYLE_BASE64));
     }
@@ -911,40 +987,6 @@ public class YAMLGenerator extends GeneratorBase
                 null, null, style);
     }
 
-    // // // 26-Feb-2019, tatu: Copied temporarily (for 2.10) from `Base64Variant` to prevent
-    // // //   hard dependency for same minor version
-
-    private String _base64encode(final Base64Variant b64v, final byte[] input, final String linefeed)
-    {
-        final int inputEnd = input.length;
-        final StringBuilder sb = new StringBuilder(inputEnd + (inputEnd >> 2) + (inputEnd >> 3));
-
-        int chunksBeforeLF = b64v.getMaxLineLength() >> 2;
-
-        int inputPtr = 0;
-        int safeInputEnd = inputEnd-3;
-
-        while (inputPtr <= safeInputEnd) {
-            int b24 = ((int) input[inputPtr++]) << 8;
-            b24 |= ((int) input[inputPtr++]) & 0xFF;
-            b24 = (b24 << 8) | (((int) input[inputPtr++]) & 0xFF);
-            b64v.encodeBase64Chunk(sb, b24);
-            if (--chunksBeforeLF <= 0) {
-                sb.append(linefeed);
-                chunksBeforeLF = b64v.getMaxLineLength() >> 2;
-            }
-        }
-        int inputLeft = inputEnd - inputPtr;
-        if (inputLeft > 0) {
-            int b24 = ((int) input[inputPtr++]) << 16;
-            if (inputLeft == 2) {
-                b24 |= (((int) input[inputPtr++]) & 0xFF) << 8;
-            }
-            b64v.encodeBase64Partial(sb, b24, inputLeft);
-        }
-        return sb.toString();
-    }
-
     protected String _lf() {
         return _outputOptions.getLineBreak().getString();
     }
